Module prelude

Module prelude 

Convenience re-export of common members

Like the standard library’s prelude, this module simplifies importing of common items. Unlike the standard prelude, the contents of this module must be imported manually:

use rand::prelude::*;

Re-exports

pub use prelude::Distribution;
pub use prelude::SmallRng;
pub use prelude::StdRng;
pub use prelude::ThreadRng;
pub use prelude::IndexedMutRandom;
pub use prelude::IndexedRandom;
pub use prelude::IteratorRandom;
pub use prelude::SliceRandom;
pub use prelude::CryptoRng;
pub use prelude::Rng;
pub use prelude::RngCore;
pub use prelude::SeedableRng;